summaryrefslogtreecommitdiff
path: root/src/format/dex/pool.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/format/dex/pool.h')
-rw-r--r--src/format/dex/pool.h31
1 files changed, 25 insertions, 6 deletions
diff --git a/src/format/dex/pool.h b/src/format/dex/pool.h
index e947465..df02ed8 100644
--- a/src/format/dex/pool.h
+++ b/src/format/dex/pool.h
@@ -25,7 +25,9 @@
#define _FORMAT_DEX_POOL_H
+#include "class.h"
#include "dex.h"
+#include "method.h"
#include "../../analysis/routine.h"
@@ -36,22 +38,39 @@ bool find_all_dex_strings(GDexFormat *);
/* Extrait une chaîne de caractères d'une table DEX. */
const char *get_string_from_dex_pool(const GDexFormat *, uint32_t);
-/* Extrait une représentation de type d'une table DEX. */
-GDataType *get_type_from_dex_pool(const GDexFormat *, uint16_t);
-/* Extrait une représentation de classe d'une table DEX. */
-GDataType *get_class_from_dex_pool(const GDexFormat *, uint32_t);
+/* Charge en mémoire l'ensemble des types du format DEX. */
+bool load_all_dex_types(GDexFormat *);
+/* Extrait une représentation de type d'une table DEX. */
+GDataType *get_type_from_dex_pool(GDexFormat *, uint32_t);
+/* Charge en mémoire l'ensemble des champs du format DEX. */
+bool load_all_dex_fields(GDexFormat *);
/* Extrait une représentation de champ d'une table DEX. */
-GBinVariable *get_field_from_dex_pool(const GDexFormat *, uint32_t);
+GBinVariable *get_field_from_dex_pool(GDexFormat *, uint32_t);
+
+/* Charge tous les prototypes listés dans le contenu binaire. */
+bool load_all_dex_prototypes(GDexFormat *);
/* Extrait une représentation de routine d'une table DEX. */
-GBinRoutine *get_routine_from_dex_pool(const GDexFormat *, uint32_t);
+GBinRoutine *get_prototype_from_dex_pool(GDexFormat *, uint32_t);
+
+/* Charge toutes les méthodes listées dans le contenu binaire. */
+bool load_all_dex_methods(GDexFormat *);
+
+/* Extrait une représentation de méthode d'une table DEX. */
+GDexMethod *get_method_from_dex_pool(GDexFormat *, uint32_t);
+
+/* Charge toutes les classes listées dans le contenu binaire. */
+bool load_all_dex_classes(GDexFormat *);
+
+/* Extrait une représentation de classe d'une table DEX. */
+GDexClass *get_class_from_dex_pool(GDexFormat *, uint32_t);